@@ -1,4 +1,4 @@
-from tapystry.main import Call, CallFork
+from tapystry.main import Call, CallFork, run
 
 from functools import wraps
 
@@ -16,3 +16,14 @@ def as_effect(forked=False):
                 return Call(f, args=args, kwargs=kwargs)
         return wrapper
     return decorator
+
+
+def runnable(f):
+    """
+    Wraps a tapestry generator and turns it into a normal function.
+    Use on top-level things that you would tap.run
+    """
+    @wraps(f)
+    def wrapper(*args, **kwargs):
+        return run(f, args=args, kwargs=kwargs)
+    return wrapper
